@@ -18,7 +18,8 @@
 #include "../include/Dialog_Partition_Info.h"
 #include "../include/LVM2_PV_Info.h"
 
-#include <gtkmm/separator.h>
+#include <gtk/gtk.h>
+#include <gtkmm/alignment.h>
 
 namespace GParted
 {
@@ -27,14 +28,39 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition )
 {
 	this ->partition = partition ;
 
-	this ->set_resizable( false ) ;
 	this ->set_has_separator( false ) ;
-	
+	//Set minimum dialog height so it fits on an 800x600 screen without
+	//  too much whitespace (~500 px max for GNOME desktop).
+	//  Allow extra space if have messages or LVM2 PV
+	if (   partition .messages .size() > 0
+	    || partition .filesystem == FS_LVM2_PV
+	   )
+		this ->set_size_request( -1, 460) ;
+	else
+		this ->set_size_request( -1, 370 ) ;	//Minimum 370 to avoid scrolling on Fedora 20
+
 	/*TO TRANSLATORS: dialogtitle, looks like Information about /dev/hda3 */
 	this ->set_title( String::ucompose( _("Information about %1"), partition .get_path() ) );
-	 
+
 	init_drawingarea() ;
-	
+
+	//place info and optional messages in scrollable window
+	info_msg_vbox .set_border_width( 6 ) ;
+	info_scrolled .set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC ) ;
+	info_scrolled .add( info_msg_vbox ) ;
+	//As Gtk::VBox widget info_msg_vbox doesn't have a native scrolling capability a
+	//  Gtk::Viewport is automatically created to contain it when it is added to the
+	//  Gtk::ScrolledWindow widget info_scrolled.  The Viewport widget is created with
+	//  shadow type GTK_SHADOW_IN by default.  Change to GTK_SHADOW_NONE.  Have to use
+	//  GTK+ C API as the Viewport widget isn't exposed via gtkmm C++ API.
+	//  https://developer.gnome.org/gtkmm/2.24/classGtk_1_1ScrolledWindow.html#a17c588d56d93923841d38f0d5e2ec9d7
+	GtkWidget * scrollable_child = gtk_bin_get_child(GTK_BIN(info_scrolled.gobj()));
+	gtk_viewport_set_shadow_type(GTK_VIEWPORT(scrollable_child), GTK_SHADOW_NONE);
+	//horizontally center the information scrolled window to match partition graphic
+	Gtk::Alignment * center_widget = manage( new Gtk::Alignment(0.5, 0.5, 0.0, 1.0) ) ;
+	center_widget ->add( info_scrolled ) ;
+	this ->get_vbox() ->pack_start( *center_widget ) ;
+
 	//add label for detail and fill with relevant info
 	Display_Info() ;
 	
@@ -42,8 +68,7 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition )
 	if ( partition .messages .size() > 0 )
 	{
 		frame = manage( new Gtk::Frame() );
-		frame ->set_border_width( 10 );
-		
+
 		{
 			Gtk::Image* image(manage(new Gtk::Image(Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON)));
 
@@ -82,9 +107,9 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition )
 		vbox ->pack_start( *Utils::mk_label( all_messages, true, true, true ), Gtk::PACK_SHRINK ) ;
 		frame ->add( *vbox ) ;
 
-		this ->get_vbox() ->pack_start( *frame, Gtk::PACK_SHRINK ) ;
+		info_msg_vbox .pack_start( *frame, Gtk::PACK_EXPAND_WIDGET ) ;
 	}
-		
+
 	this ->add_button( Gtk::Stock::CLOSE, Gtk::RESPONSE_OK ) ;
 	this ->show_all_children() ;
 }
@@ -178,126 +203,90 @@ void Dialog_Partition_Info::init_drawingarea()
 }
 
 void Dialog_Partition_Info::Display_Info()
-{  
-	int top = 0, bottom = 1 ;
+{
+	//The information in this area is in table format.
+	//
+	//For example:
+	//<-------------------------- Column Numbers ----------------------------->
+	//0 1            2             3             4            5               6
+	//+-+------------+-------------+-------------+------------+---------------+
+	//Section
+	//  Field Left:  Value Left    Field Right:  Value Right  Optional Right
+	//+-+------------+-------------+-------------+------------+---------------+
+	//0 1            2             3             4            5               6
+
 	Sector ptn_sectors = partition .get_sector_length() ;
+
 	LVM2_PV_Info lvm2_pv_info ;
+	Glib::ustring vgname = "" ;  //Also used in partition status message
+	if ( partition .filesystem == FS_LVM2_PV )
+		vgname = lvm2_pv_info .get_vg_name( partition .get_path() ) ;
+
+	//initialize table top and bottom row number attach trackers
+	int top = 0     , bottom = 1 ;      //Left field & value pairs
+	int topright = 0, bottomright = 1 ; //Right field & value pairs
 
 	Gtk::Table* table(manage(new Gtk::Table()));
 
 	table ->set_border_width( 5 ) ;
 	table ->set_col_spacings(10 ) ;
-	this ->get_vbox() ->pack_start( *table, Gtk::PACK_SHRINK ) ;
-	
-	//filesystem
+	info_msg_vbox .pack_start( *table, Gtk::PACK_SHRINK ) ;
+
+	//FILE SYSTEM DETAIL SECTION
+	//file system headline
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("File System") ) + "</b>" ),
+			0, 6,
+			top++, bottom++,
+			Gtk::FILL ) ;
+
+	//use current left row tracker position as anchor for right
+	topright = top ;
+	bottomright = bottom ;
+
+	//Left field & value pair area
+	//file system
 	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("File system:") ) + "</b>" ),
-			0, 1,
+			1, 2,
 			top, bottom,
 			Gtk::FILL ) ;
 	table ->attach( * Utils::mk_label( Utils::get_filesystem_string( partition .filesystem ), true, false, true ),
-			1, 2,
+			2, 3,
 			top++, bottom++,
 			Gtk::FILL ) ;
 
-	//size
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Size:") ) + "</b>" ),
-			0, 1,
-			top, bottom,
-			Gtk::FILL) ;
-	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, false, true ),
-			1, 2,
-			top++, bottom++,
-			Gtk::FILL ) ;
-	
-	if ( partition .sector_usage_known() )
+	//label
+	if ( partition.type != GParted::TYPE_UNALLOCATED && partition.type != GParted::TYPE_EXTENDED )
 	{
-		//calculate relative diskusage
-		int percent_used, percent_unused, percent_unallocated ;
-		partition .get_usage_triple( 100, percent_used, percent_unused, percent_unallocated ) ;
-
-		//Used
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Used:") ) + "</b>" ),
-				0, 1,
-				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, false, true ),
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Label:") ) + "</b>"),
 				1, 2,
 				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_used ) + "% )"),
-				1, 2,
+				Gtk::FILL) ;
+		table ->attach( * Utils::mk_label( partition .get_label(), true, false, true ),
+				2, 3,
 				top++, bottom++,
-				Gtk::FILL ) ;
-
-		//unused
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unused:") ) + "</b>" ),
-				0, 1,
-				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, false, true ),
-				1, 2,
-				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_unused ) + "% )"),
-				1, 2,
-				top++, bottom++,
-				Gtk::FILL ) ;
-
-		//unallocated
-		Sector sectors_unallocated = partition .get_sectors_unallocated() ;
-		if ( sectors_unallocated > 0 )
-		{
-			table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unallocated:") ) + "</b>" ),
-					0, 1,
-					top, bottom,
-					Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, false, true ),
-					1, 2,
-					top, bottom,
-					Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_unallocated ) + "% )"),
-					1, 2,
-					top++, bottom++,
-					Gtk::FILL ) ;
-		}
+				Gtk::FILL) ;
 	}
 
-	Glib::ustring vgname = "" ;
-	if ( partition .filesystem == FS_LVM2_PV )
-		vgname = lvm2_pv_info .get_vg_name( partition .get_path() ) ;
-
-	//flags
-	if ( partition.type != GParted::TYPE_UNALLOCATED )
+	//uuid
+	if ( partition.type != GParted::TYPE_UNALLOCATED && partition.type != GParted::TYPE_EXTENDED )
 	{
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Flags:") ) + "</b>" ),
-				0, 1,
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("UUID:") ) + "</b>"),
+				1, 2,
 				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Glib::build_path( ", ", partition .flags ), true, false, true ),
-				1, 2, 
+				Gtk::FILL) ;
+		table ->attach( * Utils::mk_label( partition .uuid, true, false, true ),
+				2, 3,
 				top++, bottom++,
-				Gtk::FILL ) ;
+				Gtk::FILL) ;
 	}
-	
-	//one blank line
-	table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
-	
+
+	//status
 	if ( partition .type != GParted::TYPE_UNALLOCATED && partition .status != GParted::STAT_NEW )
 	{
-		//path
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>" ),
-				0, 1,
-				top, bottom,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Glib::build_path( "\n", partition .get_paths() ), true, false, true ),
-				1, 2,
-				top++, bottom++,
-				Gtk::FILL ) ;
-		
 		//status
 		Glib::ustring str_temp ;
 		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Status:") ) + "</b>" ),
-				0, 1,
+				1, 2,
 				top, bottom,
 				Gtk::FILL ) ;
 		if ( partition .busy )
@@ -308,29 +297,22 @@ void Dialog_Partition_Info::Display_Info()
 				 * means that this extended partition contains at least one logical
 				 * partition that is mounted or otherwise active.
 				 */
-				str_temp =  _("Busy (At least one logical partition is mounted)") ;
+				str_temp = _("Busy (At least one logical partition is mounted)") ;
 			}
 			else if (    partition .filesystem == FS_LINUX_SWAP
 			          || partition .filesystem == FS_LINUX_SWRAID
-			        )
+			          || partition .filesystem == FS_LVM2_PV
+			         )
 			{
 				/* TO TRANSLATORS:  Active
-				 * means that this linux swap or linux software raid partition
-				 * is enabled and being used by the operating system.
+				 * means that this linux swap, linux software raid partition, or
+				 * LVM physical volume is enabled and being used by the operating system.
 				 */
 				str_temp = _("Active") ;
 			}
-			else if ( partition .filesystem == FS_LVM2_PV )
-			{
-				/* TO TRANSLATORS:  myvgname active
-				 * means that the partition is a member of an LVM volume group and the
-				 * volume group is active and being used by the operating system.
-				 */
-				str_temp = String::ucompose( _("%1 active"), vgname ) ;
-			}
 			else if ( partition .get_mountpoints() .size() )
 			{
-				str_temp = String::ucompose( 
+				str_temp = String::ucompose(
 						/* TO TRANSLATORS: looks like   Mounted on /mnt/mymountpoint */
 						_("Mounted on %1"),
 						Glib::build_path( ", ", partition .get_mountpoints() ) ) ;
@@ -364,19 +346,19 @@ void Dialog_Partition_Info::Display_Info()
 				 */
 				str_temp = _("Not active (Not a member of any volume group)") ;
 			else if ( lvm2_pv_info .is_vg_exported( vgname ) )
-				/* TO TRANSLATORS:  myvgname not active and exported
+				/* TO TRANSLATORS:  Not active and exported
 				 * means that the partition is a member of an LVM volume group but
 				 * the volume group is not active and not being used by the operating system.
 				 * The volume group has also been exported making the LVM physical volumes
 				 * ready for moving to a different computer system.
 				 */
-				str_temp = String::ucompose( _("%1 not active and exported"), vgname ) ;
+				str_temp = _("Not active and exported") ;
 			else
-				/* TO TRANSLATORS:  myvgname not active
+				/* TO TRANSLATORS:  Not active
 				 * means that the partition is a member of an LVM volume group but
 				 * the volume group is not active and not being used by the operating system.
 				 */
-				str_temp = String::ucompose( _("%1 not active"), vgname ) ;
+				str_temp = _("Not active") ;
 		}
 		else
 		{
@@ -386,108 +368,178 @@ void Dialog_Partition_Info::Display_Info()
 			str_temp = _("Not mounted") ;
 		}
 
-		table ->attach( * Utils::mk_label( str_temp, true, false, true ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( str_temp, true, false, true ), 2, 3, top++, bottom++, Gtk::FILL ) ;
 	}
 
-	//label
-	if ( partition.type != GParted::TYPE_UNALLOCATED && partition.type != GParted::TYPE_EXTENDED )
-	{
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Label:") ) + "</b>"),
-				0, 1,
-				top, bottom,
-				Gtk::FILL) ;
-		table ->attach( * Utils::mk_label( partition .get_label(), true, false, true ),
-				1, 2,
-				top++, bottom++,
-				Gtk::FILL) ;
-	}
-
-	//uuid
-	if ( partition.type != GParted::TYPE_UNALLOCATED && partition.type != GParted::TYPE_EXTENDED )
-	{
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("UUID:") ) + "</b>"),
-				0, 1,
-				top, bottom,
-				Gtk::FILL) ;
-		table ->attach( * Utils::mk_label( partition .uuid, true, false, true ),
-				1, 2,
-				top++, bottom++,
-				Gtk::FILL) ;
-	}
-
-	//one blank line
-	table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
-	
-	//first sector
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("First sector:") ) + "</b>" ),
-			0, 1,
-			top, bottom,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .sector_start ), true, false, true ),
-			1, 2,
-			top++, bottom++,
-			Gtk::FILL ) ;
-	
-	//last sector
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Last sector:") ) + "</b>" ),
-			0, 1,
-			top, bottom,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition.sector_end ), true, false, true ),
-			1, 2,
-			top++, bottom++,
-			Gtk::FILL ) ; 
-	
-	//total sectors
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Total sectors:") ) + "</b>" ),
-			0, 1,
-			top, bottom,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, false, true ),
-			1, 2,
-			top++, bottom++,
-			Gtk::FILL ) ;
-
+	//Optional Logical Volume Manager Physical Volume details
 	if ( partition .filesystem == FS_LVM2_PV )
 	{
-		//one blank line
-		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
-
-		//horizontal separator
-		Gtk::HSeparator * hsep( manage( new Gtk::HSeparator() ) ) ;
-		table ->attach( * hsep, 0, 2, top++, bottom++, Gtk::FILL ) ;
-
-		//one blank line
-		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
-
 		//Volume Group
 		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Volume Group:") ) + "</b>"),
-		                0, 1, top, bottom, Gtk::FILL ) ;
+		                1, 2, top, bottom, Gtk::FILL ) ;
 		table ->attach( * Utils::mk_label( vgname, true, false, true ),
-		                1, 2, top++, bottom++, Gtk::FILL ) ;
+		                2, 3, top++, bottom++, Gtk::FILL ) ;
 
 		//Members
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Members:") ) + "</b>"),
-		                0, 1, top, bottom, Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Members:") ) + "</b>", true, false, false, 0.0 /* ALIGN_TOP */ ),
+		                1, 2, top, bottom, Gtk::FILL ) ;
 
 		std::vector<Glib::ustring> members ;
 		if ( ! vgname .empty() )
 			members = lvm2_pv_info .get_vg_members( vgname ) ;
 
-		if ( members .empty() )
-			table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
-		else
+		Glib::ustring members_str = "" ;
+		if ( ! members .empty() )
 		{
-			table ->attach( * Utils::mk_label( members [0], true, false, true ),
-			                1, 2, top++, bottom++, Gtk::FILL ) ;
-			for ( unsigned int i = 1 ; i < members .size() ; i ++ )
+			for ( unsigned int i = 0 ; i < members .size() ; i ++ )
 			{
-				table ->attach( * Utils::mk_label( "" ), 0, 1, top, bottom, Gtk::FILL) ;
-				table ->attach( * Utils::mk_label( members [i], true, false, true ),
-				                1, 2, top++, bottom++, Gtk::FILL ) ;
+				if ( i > 0 )
+					members_str += "\n" ;
+				members_str += members[i] ;
 			}
 		}
+		table ->attach( * Utils::mk_label( members_str, true, false, true, 0.0 /* ALIGN_TOP */ ), 2, 3, top++, bottom++, Gtk::FILL ) ;
 	}
+
+	//Right field & value pair area
+	if ( partition .sector_usage_known() )
+	{
+		//calculate relative diskusage
+		int percent_used, percent_unused, percent_unallocated ;
+		partition .get_usage_triple( 100, percent_used, percent_unused, percent_unallocated ) ;
+
+		//Used
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Used:") ) + "</b>" ),
+				3, 4,
+				topright, bottomright,
+				Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, false, true ),
+				4, 5,
+				topright, bottomright,
+				Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_used ) + "% )"),
+				5, 6,
+				topright++, bottomright++,
+				Gtk::FILL ) ;
+
+		//unused
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unused:") ) + "</b>" ),
+				3, 4,
+				topright, bottomright,
+				Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, false, true ),
+				4, 5,
+				topright, bottomright,
+				Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_unused ) + "% )"),
+				5, 6,
+				topright++, bottomright++,
+				Gtk::FILL ) ;
+
+		//unallocated
+		Sector sectors_unallocated = partition .get_sectors_unallocated() ;
+		if ( sectors_unallocated > 0 )
+		{
+			table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unallocated:") ) + "</b>" ),
+					3, 4,
+					topright, bottomright,
+					Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, false, true ),
+					4, 5,
+					topright, bottomright,
+					Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_unallocated ) + "% )"),
+					5, 6,
+					topright++, bottomright++,
+					Gtk::FILL ) ;
+		}
+	}
+
+	//size
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Size:") ) + "</b>" ),
+			3, 4,
+			topright, bottomright,
+			Gtk::FILL) ;
+	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, false, true ),
+			4, 5,
+			topright++, bottomright++,
+			Gtk::FILL ) ;
+
+	//ensure left row tracker set to largest side (left/right)
+	top = std::max( top, topright );
+	bottom = std::max( bottom, bottomright );
+
+	//one blank line
+	table ->attach( * Utils::mk_label( "" ), 0, 6, top++, bottom++, Gtk::FILL ) ;
+
+	//PARTITION DETAIL SECTION
+	//partition headline
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Partition") ) + "</b>" ),
+			0, 6,
+			top++, bottom++,
+			Gtk::FILL ) ;
+
+	//use current left row tracker position as anchor for right
+	topright = top ;
+	bottomright = bottom ;
+
+	//Left field & value pair area
+	//path
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>" ),
+			1, 2,
+			top, bottom,
+			Gtk::FILL ) ;
+	table ->attach( * Utils::mk_label( Glib::build_path( "\n", partition .get_paths() ), true, false, true ),
+			2, 3,
+			top++, bottom++,
+			Gtk::FILL ) ;
+
+	if ( partition .type != GParted::TYPE_UNALLOCATED && partition .status != GParted::STAT_NEW )
+	{
+		//flags
+		if ( partition.type != GParted::TYPE_UNALLOCATED )
+		{
+			table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Flags:") ) + "</b>" ),
+					1, 2,
+					top, bottom,
+					Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( Glib::build_path( ", ", partition .flags ), true, false, true ),
+					2, 3,
+					top++, bottom++,
+					Gtk::FILL ) ;
+		}
+	}
+
+	//Right field & value pair area
+	//first sector
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("First sector:") ) + "</b>" ),
+			3, 4,
+			topright, bottomright,
+			Gtk::FILL ) ;
+	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .sector_start ), true, false, true ),
+			4, 5,
+			topright++, bottomright++,
+			Gtk::FILL ) ;
+	
+	//last sector
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Last sector:") ) + "</b>" ),
+			3, 4,
+			topright, bottomright,
+			Gtk::FILL ) ;
+	table ->attach( * Utils::mk_label( Utils::num_to_str( partition.sector_end ), true, false, true ),
+			4, 5,
+			topright++, bottomright++,
+			Gtk::FILL ) ; 
+	
+	//total sectors
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Total sectors:") ) + "</b>" ),
+			3, 4,
+			topright, bottomright,
+			Gtk::FILL ) ;
+	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, false, true ),
+			4, 5,
+			topright++, bottomright++,
+			Gtk::FILL ) ;
 }
 
 Dialog_Partition_Info::~Dialog_Partition_Info()
